Recueil langues
Table des dispositions (26)
Texte législatif (26 Articles)
nett, Musel); plazeweis gët et duerbäi nach zweërlee laangen ä [ε:/æ:] (Belsch Säit, Uewermusel). 'T fënt een och zweërlee laangen o [o:/ɔ:] (Iewescht
Éislek, Ënnescht Guttland) odder a [a:/α:] (Wolzer Streech, Mierscherdall, Ënnescht Guttland, esouguer [ø:] ö an [ə:] ë niefteneen (Ënnescht Éislek).
Vgl. Sonner Sproochen.
Langues
[ᴜ:]
fr. ou, oû
Clou, Cours, Filou, Goût, Ragoût, Retour, Tout-à-l’égout
[o:]
fr. au, eau
Auberge, Chauffeur, Chalumeau, Niveau, Panneau, Plateau
[e:]
fr. é
Bëbé(!), Café(ma mir drénke Kaffi), Congé, Coupé, Paté
[ɛ:/æ:]
fr. ai, è, ê
Arrêt, Contraire, Crême, Etagère, Forfait, Quête, Retraite
[ᾶ:]
fr. an, en/lëtz. â, ê
Banquet, Chance, Hortense, Menthe/Châmber, Châncen, Mêmber
[˜ɛ:]
fr. ain, ein, in, un, yn(-m)/lëtz. î, û
Copain, Ceinture, Pince, Thym/hûmbel, Tîmber
[˜ɔ:]
fr. on/lëtz. ô
Ballon, Bon, Fonds, Jeton, Rond-point/Cômbel, plômbéieren
D’franséisch Laangvokaler « duurch d’Nues » kiirzt de Lëtzebuerger gär of mat engem ng[ƞ] hannendrun: Bong, Fong, Koséng,
Kulang, Tirang, Tire-buschong, Wolang.
3. Duebelvokaler: ai, au, äi, äu, éi, ëu, ie, ue*) — [αᶦ], [αᵘ], [ `æ:ɪ], [ `æ:ᴜ], [eᶦ], [Ɵᵘ], [ɪᵊ/ì:ə], [ᴜᵊ/ `ᴜ:ə].
Eis Ëmgankssprooch kennt 8 Vokalkoppelen (Diphthongen) mat den Hallefvokaler i an u. Bei allen aacht läit den Haapttoun um
viischte Laut.
Dräi gin dër anescht geschriwwe wéi geschwat
ëu [Ɵᵘ] schreift sech ou (d’lescht Jorhonnert huet nach en o eraushéieren),
ai [αᶦ] schreift sech ei (nom Däitschen), ma als au-Ëmlaut ai,
äu [`æ:ᴜ,`ɛᴜ:] schreift sech grad ewéi au.
Fir méi genee ze sin, léiss sech och ëu an äu huelen, ma den Dixionär mécht dat nët, wéinst dem franséischen eu(= ö) an dem däitschen
eu, äu(= oi).
Halleflaang an iwwerlaang Duebelvokaler ënnerschede mer nët an der Schrëft.
ie [ɪᵊ/ì:ə]
an ue [ᴜᵊ/`ᴜ:ə]
(hallef-/iwwerlaang) stin eemol wéi d’anertmol,
éi [eᶦ]
an ëu [Ɵᵘ]
(halleflaang) schreiwe sech éi an ou,
äi [`æ:ɪ/`ɛɪ:]
an äu [`æ:ᴜ/`æ:ᴜ:] (iwwerlaang) zeechne mer jhust hallef (äi, ma au = äu/au),
ai [αᶦ]
an au [αᵘ]
(halleflaang) sti gewéinlech als ei an au nom Däitschen;
ai steet, wou d’Däitscht au, äu huet an als Ëmlaut.
Geléint Wierder behalen en och: Detail, Pai, Paiaass, Tail.
Den ai/äi-Ëmlaut as zweegleiseg; e soll duerfir däitlech geschriwwe gin
ai gët Ëmlaut vun au an äu: sauer-Saier/Bau-Gebai; äi vum äu eleng: Schlauch-Schläich.
Eisen äu huet zweërlee Ëmlaut (äi/ai), an dat no dëser Regel
Westgerm. û > lëtzeb. äu/au laut ëm op äi/ai viru schaarfe/mëlle Lauter an der aler Endong: Fäischt(Fäuste), Schläich(Schläuche),
ma: Lais(Läuse), Mais(Mäuse).
D’Hollännescht kann och de Verglach gin: Hait, Kraider (ndl. huiden, kruiden < germ. d, nët hd. t; duerfir lëtzeb. ai, nët äi. Vgl.
KONSONANTEN 2b.
Wéi no laange Vokaler schreift een no Duebelvokaler kee Konsonant zweemol oons de schaarfen ss, keen ck a keen tz.
au (= au): Bauer, Drauf, haut, Kaul, Klaus, lauden, Mauer, Rau, schlau, Schrau, trauen
au (= äu): Braut, Dausch, elauter, eraus, Haut, Klauschter, Raut, Strauss, Trausch
äi
Äis, bäissen, däischter, fräi, Läim, näischt, Päif, Schwäin, wäiss, wäit
ei/ai
Beidel, dreiwen, Gei, Leit, nei, weit ; Gezai, Raiber, schaimen, Straiss, Traisch
éi
béis, Déier, géi, héich, Kéier, Kléi, kréien, séier, Schnéi, Tréier, Wéischt, zéi
ie
Biesem, diebelen, fierwen, giel, Hiecht, lieweg, mierf, Ried, Schiet, Wiel, Ziedel
ou
Bouf, Dous, esou, frou, Kouert, Mous, Poul, roueg, Stouss, wouer, Wouscht, zou
ue
Buedem, duer, fueren, huel, Juegd, Kuel, Kuerf, lueden, Ruecht, Suerg, Uewen
Eis r-Regel no Duebelvokaler
Halleflaang ai/ei, au, éi, ou gët et wuel virun -er, ma nët virum -r
Auer, Faier, Leier, Ouer, Schéier. (No Duebelvokaler kritt den e keng Ponkten !)
Iwwerlaang äu an äi stin an der Emgankssprooch néierewou virun -r odder -er; ie an ue stin als eenzeg Duebelvokaler virum
-r, ma si sti keemol um Enn vum Wuert. Nëmme wann en -n ewechfällt, komme se duer: hie kënnt, wie seet ? (= jhust bei dien, hien,
wien). Virun ch[ç], j, k gin se bal ié, ué [ɪ:ë], [ᴜ:ë] geschwat, ma dat schreiwe mer nët.
E verwëschten r hannert ie-, ue- muss geschriwwe gin.
Duerfir: Wuer gees de ? (nët: Wue gees de ?) — Duerhannen (nët: Duehannen).
(Fir den echten ie, ue vum verschlaffenen ir, ur (< ier, uer) z’ënnerscheden, vgl. d’r-Regel no laange Vokaler.)
*) ie an ue [ıə/ı:ə], [ᴜə/ᴜ:ə] splécken sech allebéid op an 2 Phonemer — halleflaang an iwwerlaang, z.B. Bier « Bahre » [ıə] ≠ Bier « Bär » [ı:ə]; muer « morgen » [ᴜə] ≠ Muer
« Moor » [ᴜ:ə]. Am Monn vun der jéngster Generatioun verwëscht deen Ënnerscheed sech ewéi d'Hallef- an d'Iwwerlängt iwwerhaapt. Ma [ı:ə > ıə], [ᴜ:ə > ᴜə] si phonetesch
kees ze verwiessele mat den zweesilbegen [i:ə], [ᴜ:ə], déi mer ië, uë schreiwen; uechtgin op [ı ≠ i] an [ᴜ ≠ u], z.B. Schwier « Schwäre » [ı:ə] ≠ schwiër « schwer » (Éislek,
Sauer) [i:ə], Wuer « Ware » [ᴜ:ə] ≠ wuër « wahr » (Éislek, Sauer) [ᴜ:ə]. An der Längt as et enges, ma den Usaz an den Iwwergank si verschidden; dat deet äis [ı:ə], [ᴜ:ə]
monophonematesch an [i:ə], [ᴜ:ə] biphonematesch opfaassen. Vgl. Sonner Sproochen.
Langues
Geléint däitsch a geléiert Wierder hun och [ɔʏ] = eu, äu; wou en op lëtzebuergesch virkënnt, gët oi geschriwwen. Franséisch
Vokalkoppelen ewéi ay, oi, ui asw. zielen nët fir Duebelvokaler; mir ernimmen se jhust wéinst der Schrëft.
[ɔʏ]
dt. eu, äu
enttäuscht, Heuchler ; griich. eu: Europa, neutral, Rheuma;
wa lëtzeb., dann oi: Moiën(>Muergen), Oijee(>Oeuillet)
[αɪ:]
fr. ail, aï, ay
Bail, Detail, Email, Faïence, Faillite, Maillot, Mayonnaise
[ɛɪ:]
fr. ay, eil
Conseiller, Corbeille, Crayon, Paysage, Rëveillon, vermeil
[Ɵɪ:]
fr. euil, oueil
Chevreuil, Deuil, Fauteuil, Feuille de route, Oeuillet
[ᴜɪ:]
fr. ouil
Bouillon, Brouillon, débrouilléieren, Douille, Fouille
[ᵘα/ᵘa:]: fr. oi
Coiffeur, Convoi, Droit, Toile cirée, Toilette, Trottoir, Voile
[ᵘαɪ]
fr. oy
Employé, Foyer, Loyer, Moyen, Moyenne, Voyageur, voyons !
[ʏɪ/ʏi:]
fr. ui, uy
Ennui, Fuite, Huis clos, Huissier, Puisette, Suite, Tuyau
[ɪe:]
fr. ié, ie
Associé, Courrier, Epicier, Pied-à-terre, Portier, Rentier
[ɪɛ/ɪɛ:]
fr. iè, ie
Barrière, Carrière, Pièce, Pierre, Première, Relief, Siège
Geléint englesch, italiéinesch a soss friem Wierder behale meeschtens och hir Vokaler; mir gin nët extra hei drop an.
4. Vokaler an onbetounte Silben.
Eis Haaptregele gëlle fir betount Vokaler. An onbetounte Silben as de Vokal zum dackste kuurz; duerfir setzt een do gewéinlech
kee Konsonant duebel derhannert.
Virsilben
Bagaasch, Bromee, Familjen, Figur, Galosch, Kamäin, Kuraasch, Manéier, Reklam;
Ennsilben
Begänknis, Dëmpel, Gellep, Kinnigin, Pillem, Schappen, Sieschter, Sinnef, wëlles.
Wéi am Däitsche gët kees verduebelt bei -el, -em, -en, -er, -es, -in, -is.
No laange Vokaler kritt och den onbetounten ë Tëppelen, ma all Kéier muss een se nët setzen: Aën, Eër(Är), froën, goën, haën, Hoër,
Leër(Lär) , Schiër(Skier), Suën(sous).
Wann een awer ganz Wierder uneneesetzt, schreift een dat onbetount och, wéi wann et eleng sting, d.h. d’kuurz Vokaler mam
duebele Konsonant
Aärdnëss, Grummwiss, Hondsmëll, Kappstëmm, Klinnsprëss, Setzënn, Spatzminn.
Franséisch Wierder behale gär hir Schrëft, och wa mir s’anescht betounen. Bei äis kritt ewéi am Däitsche ganz dacks d’viischt
Silb den Akzent, ma duerfir muss hei nët all Konsonant duebel gesat gin
Bëtong, Brëtell, Brigang, Brikett, Fiténg, Galong, Karaff, Kulang, Modell, Notär, Paraff, Rido, Rubarb, Salong, Tirage, Zigar.
Wann d’Wuert ewell méi eng Lëtzebuerger Fassong huet odder schons eng däitsch besteet, da kënne mer och no eiser
Grondregel fueren (d’Konsonante verduebelen)
Ammelett, Fritten, Giddong, Gubbeli(Gubli), Jhilli, kammoud, Monnonk (= mon oncle), Mattant (= ma tante). Den Dixionär schreift
och: Mamma, Pappa (wéinst der Betounong).
Uecht gin op véiererlee Endongen
-ek
liese mer -éck [ek]: Billek
-eck
liese mer -äck
[ɛk]: Motzeck
-el
liese mer -ëll
[əl]
Bëtschel
-ell
liese mer -äll
[æl]: Flanell
-éng
liese mer -éng [eη]: Koséng
-eng
liese mer -äng
[ɛη]: eleng
-et
liese mer -ët
[ət]
et (dat, hatt)
-ett
liese mer -ätt
[æt]: Forschett
Bei -ef, -el, -em, -en, -ep, -er, -es, -esch as bal ëmmer ë[ə] gemengt, bei -ech(-eg) ëmmer é[e]. Franséisch Wierder op -elle, -enne,
-esse, -ette (an iwwerhaapt Wierder mam stommen e) loosse mer dacks stoë wéi gewéinlech: Ficelle, Persienne, Vitesse, Poussette.
KONSONANTEN
Am Lëtzebuergeschen ënnerschede mer se der Längt an der Stëmm no: kuurz a laang, mëll a schaarf. Eis meescht Konsonante sin
nëmme kuurz, jhust Nues- a Säitelauter (m, n, ng [η] — l) si kuurz a laang: stall(still) — Stall(Stall), [ʃtαl] — [ʃtαl::]; wann(wenn) —
Wann(Getreidewanne), [vαn] — [vαn::].
Kuurz a laang Konsonante schreiwe mer eent ewéi d’anert. Zum éischten, well d’halleft Land keng laang schwätzt, ma an hir Plaz
d’Vokaler zitt, an och, well een eis Iwwerlängten haut nët méi esou kloër héiert wéi soss (vgl. Vokaler).
Laang Konsonanten («Schwieflauter») hu mer nëmmen no kuurze Vokaler. Si stin duerfir souwéisou duebel oons nk [`η::k], wann
nët nach Konsonanten nokommen. Mir huelen un, ʼt liest een se vum selwe richteg: -ld, -lz, -mp, -nd, -nk, -nz sin op jidde Fall laang um
Enn vum Wuert. Oons déi gin et dër nët vill, wou ee muss roden (-ll, -mm, -nn)
Bänk, Damp, Fall, Gold, Hond, Kamp, komm(gekommen), Mann, Mënz, Onk, Schëld, Walz, Zonk.
Eis Konsonantenzeeche weisen nom Dixionär zweërlee
wéilaang de Vokal virdrun dauert (Quantitéit vum Vokal)
a wéi de Konsonant selwer klénkt (Qualitéit vum Konsonant).
1. Quantitéitsregelen (vgl. Vokaler).
Duebelgeschriwwe Konsonanten, am Wuert odder um Enn, bedeite jhust, datt de Vokal virdru kuurz as. Virum eenzelne
Konsonant gët de Vokal laang gelies (vgl. Vokaler l-2).
Langues
No Duebelvokaler (Diphthongen), déi souwéisou laang sin, steet duerfir kee Konsonant zweemol. An onbetounte Silbe brauche mer
och nët ze verduebelen, well do sin eis Vokaler gemengerhand kuurz (vgl. Vokaler 3-4).
Nët all eis Konsonante loossen sech duebel schreiwen.
Verduebelt gin nëmme b/p; d/t; g[g]/k; w[v]/f; s[s]; l, m, n, r an z[ts].
Amplaz kk huele mer ck, amplaz zz[ts] steet tz. Wa mer d’Wuert splécken, as et k-k, awer t-z. Dee Grapp kuurz Wierder, wou mer kees
verduebelen, as bei de Vokaler ernimmt (1a). Wéi g an s ze schreiwe sin, widderhuele mer elei ënner (a, b) (= Vokaler Ib, c).
Vgl.: Sabel — Sabbel; Redel — Ruddel; afen — affen; Neger — Bagger; paken — packen; Bal — Ball; Krom — kromm; Pan —
Pann; Kap — Kapp; mar — Marri; Glas — lass; dat — datt; awer — iwwer; Plazen — platzen.
(a) Wann de g [j] odder [γ] geschwat gët, steet e keemol duebel; och de Vokal virdrun nët, e sief kuurz odder laang.
kuurz — [j] virun i: Kigelchen, Rigel, Sigel/[γ] virun u: Dugend, Kugel, Vugel;
laang — [j] virun i, e: Fliger, Segel/[γ] virun a, o, u: Lager, Groussherzogin, Jugend.
Wou de g als franséische [Ӡ] gelies gët, steet en och jhust eemol: Roger (o kuurz), Loge (o laang). Duebel-gg géif ëmmer [g] gelies
(vgl. Vokaler 1b).
(b) De mëllen s[z] schreiwe mer keemol duebel; de Vokal virdrun och nët, e sief kuurz odder laang.
kuurz: bëselen, Dusel, Fusel, Kisel, Rosel, Wisel;
laang: Brosi, draseg, Hesert, Osécken, Tasekëppchen, Zesi(Saisie).
Duebel-ss gët ëmmer schaarf gelies; ma och de schaarfen s steet ni duebel um Ufank vum Wuert. Nom Franséischen as et hei: Sachet,
Service, Souvenir, wann de Lëtzebuerger nët grad en z[ts] an d’Plaz schwätzt: Zaschee, Zerwiss, Zuvenir.
Konsonanten, déi mer mat 2, 3 Buschtawe schreiwen, stin néierens duebel.
Virun ch(ech-Laut/och-Laut [ç/x], jh[Ӡ], ng[ƞ], sch[ʃ] — an och virum x[ks] — muss de laange Vokal duebel stoën.
kuurz: Zich, Zuch, Pujhel, Frang, Nascht, Duxall;
laang: Liicht, Luucht, Piijhen, Schlaang, Haascht, Aax.
Bei méi Konsonante steet keemol een duebel, ‘t sief dann, d’Wuert as zesummegesat.
z.B. - kt -: Apdikt, direkt,*)
awer - ckt -
Jhicktubak, Ticktack,
- ks -: Diks (disque), diksen,
awer - cks -
décksen, Specksäit,
- lm -: Film, Schelmenaart,
awer - llm -
Bollmiel, Follmillen,
- ml -: Omlett, Rëmléng,
awer - mml -: himmlesch, nämmlech,**)
- ms -: Brems, fumsen,
awer - mmz -: flemmzeg, Hemmzert,
- nd -: Bëndel, Rondel
awer - nnd -: Sonndeg, Zänndokter asw.
Eng Flexiounsendong zielt fir e sonnert Stéck am Wuert. Haapt-, Egeschaafts- an Zäitwierder mat kuurzem Stackvokal verléieren
ni e verduebelte Konsonant virun -s, -t, -st(en), -chen asw.
déck — Déckt; dënn — Dënnt; klappen — Geklapps; wullen — Gewulls; blann Gromperen — blannt Glas; graffe Buschtaf— dat
Graffst vum Graffsten; Drëpp — Drëppchen; Fouss — Féisschen; schaffen — du schaffs, hie schafft; Och ck an tz bleiwe sin: dacks, du
strécks, hie sëtzt asw.
Opzepassen as jhust, wou een nom Däitschen nët verduebelt: hien hält, du hëls, ‘t gëlt.
D’Stacksilb mat laangem Vokal kann duurch e kuurzen Ëmlaut e Konsonant bäikréien
De Vokal muss kënne kuurz gelies gin.
Af— Äffchen; Schaf— Schäffchen; Trap — Träppchen; Zap — Zäppchen.
Sou soll een och bei den Ennsilben -ek, -ik, -in de Konsonant verduebelen, soubal -en drugehaang gët
Béckelek — Béckelécken; Éislek — Éislécker; Kiewerlek — Kiewerlécken; Mekanik — Mekanicken; Kinnigin — Kinniginnen; Léierin
— Léierinnen.
Ma den Dixionär fiert do selwer nët esou streng; ʼt geet och
Flillik — Flilliken; Kinnek — Kinneken; odder
Brilléck — Brillécken; Buttéck — Buttécker.
Ëmgekéiert heescht et, wann e Wuert deklinéiert odder konjugéiert gët odder soss eng Endong kritt, all laange Vokal
verduebelen, soubal e Konsonant baikënnt
De Vokal muss kënne laang gelies gin.
äre Pir — äärt Finn; hir Kanner — hiirt Kand; afen — Geaafs; erkalen — erkaalt; lafen — dir laaft; no — am noosten; e gudde
Rot — nët rootsem.
’T kann awer hei och emol en duebelgeschriwwene Vokal duurch eng Endong nët méi néideg sin
Biitchen — Bitercher; Kleeschen — Klesercher; Meedchen — Medercher; Reen — renen; Seel — Seler; deen - denen.
Jhust wou d’Betounong mat am Spill as, loosse mer de Vokal duebel stoën
deemools, keemol, zweemol a besonnesch eemol fir z’ënnerschede vun emol.
*
Wa mer éisléckesch schreiwen, gi mer awer de [-kt] (amplaz guttlännesch -t) mat -ckt erëm: hockt(haut), Leckt(Leit).
** D'Lëtzebuergescht ënnerscheed nämlech (= dat heescht) an d'nämmlecht (= d'selwecht).
Langues
Wann awer zwee ganz Wierder zesummegesat gin, dann ännert dat viischt nët, och nët, wann et no engem laange Vokal e
Konsonant bäikritt.
Ball — Ballspill; Dir — Dirwiechter; molen — Molkëscht; Pap — Papschossel; Ribb — Ribbsom; Sak — Sakduch. Jhust den -n fällt
aus: Reen — Reebou.
Nëmmen eemol a fir sech eleng steet de sonneren « n » tëscht onbetounte Firwierder. Wann d’onbetount Firwuert « en »(hien)
hannerun « de » odder « se »(du, si onbetount) stoë kënnt, da musse mer en n dertëschent schwätzen.
Soss géif d’Firwuert (en) mam onbestëmmten Artikel (en) verwiesselt
Hu se n en elo? Awer: Hu si en elo? Hu se hien elo?
Kenns de n en erëm? Awer: Kenns du en erëm? Kenns du hien erëm?
Verbalendonge viru Firwierder a soss am Saz stin zum Deel sonner (« s », « en »), zum Deel gin s’ un d’Firwuert drugeschriwwen
(« -t »)
An Niewesätz (eendun, ob se mat Firwierder, Frowieder odder Konjunktiounen ugin) steet virum Firwuert du(de) deen -s fir
sech, dee soss nëmmen d’Verb an der zweter Persoun kritt.
Wann s de mengs . . . , wuer s de gees . . . , wéini s de waars . . . , datt s d’et weess . . . .
Och viru mir(mer) a si(se) gouf fréier am Niewesaz dacks d’Verbalendong -e[n] (1./3. Persoun) virum Firwuert ewell geschwat: datt
en si duechten . . . , iert e mir koumen asw.
Un d’Firwuert dir, der(= ihr) an un Adverbe knëppt sech etlechmol d’Verbalendong -t fir déi 2. Persoun, wann et eng Uried odder en
Uerder soll sin: Heit ! Dot ! Sout !
De laange Vokal verduebelt sech hei, wann zwéi Konsonante beieneekommen: Nediirt ! Geldiirt !
2. Qualitéitsregelen.
Eis Schrëft deelt s’am kammoudsten esou op
Hauchlaut — Säiten-, Nues- a Schwénglauter — Verschloss- a Reiflauter — Lautkoppelen — Hallefkonsonanten.
Den Hauchlaut [h] gët nëmme geschriwwen, wou een e schwätzt, d.h. um Ufank vum Wuert. De Buschtaf h, wéi en am Däitschen
dacks nom Vokal steet (fir deen ze längen), gët et fir äis nët.
Mir schreiwe keen h, wann en nët gesot gët, z.B.: Drot, Gefor, no, Rei, Weier (däitsch: Draht, Gefahr, nahe, Reihe, Weiher).
Jhust a frieme Wierder a bei Nimm loosse mer deen h etlechmol sin, fir datt een s’eremkennt: Bühn, Fernseh, Führerschäin, Kühler,
Ohn(Ahn), Rhäin, Theater, Thees, Truh.
Wat mer natiirlech och kees schreiwen, as den Hauch um Ufank beim schaarfe Konsonant. D’Héidäitscht mécht dat och nët.
Mir schwätzen: [phà::ᴚt] — [thà::ᴚt] — [khà::ᴚt];
mir schreiwen: Paart — Taart — Kaart.
Eis Vokaler hu mëllen Asaz (franséisch), d’Konsonanten haarden (däitsch).
De bestëmmten Artikel, oons männlech/Eenzuel, (d’ = F. + N. Sing./M.F.N. Plur. = déi, dat/déi) an d’sächlecht perséinlecht Firwuert
(‘t = et, hatt) sin ouni Stëmm an ouni Hauch.
Dem Gehéier no ënnerschede mer [d] — [t/ ̥d] — [th/ ̥dh],
z.B. dee(teig) — d’Ee(das Ei) — T(Buschtaf « T », geschwat ewéi d’Hee: das Heu)
odder: déi(die) — d’Éi(die Ähre) — Téi(Tee).
Ma mir brauche keng dräi Zeechen, well d’ [ ̥d] verléiert ëmmer d’Stëmm, ‘t [t = ̥d] kritt ni den Hauch an t-[th] um Ufank virum Vokal
huet en ëmmer.
Säitelauter (l), Nueslauter (m, n, ng) a Schwénglauter (r) schreiwe sech wéi am Héidäitschen; den ng[η] virum k gët zum n
gekiirzt (nk).
Mir schreiwen: Bal, Dall, Flam, Gar, Ham, Hond, Jharr, Komp, Lann, Mamm, Numm, Pan, Plang, Rank, Schwamp, Spann, Tur,
Zaang, Zénk.
«Schwieflauter» gi keng extra gezeechent (vgl. 1).
Den -ng virum g- an zesummegesate Wierder, apaart bei ong-(on-), gët nët gekiirzt, well d’Héidäitscht keng esou Beispiller huet
onggeféier, onggemällech, onggeruet. (Mir soën awer och: ongeféier, ongemällech, ongeruet asw.)
Den r « rullt » d’Ëmgangssprooch nët, si « schappt » e bal wéi e mëllen ch. ’T as enges, ob een e mat der Zong [r] odder mat
der Strass [ᴚ,χ] schwätzt: eist Zeeche bleift r.
Bei Verschlosslauter (b/p, d/t, g/k) a Reiflauter (w[v]/f, s[z]/ss[s], jh[Ӡ]/sch[ʃ], j/ch[ç], g[γ]/ch[x]) ënnerschede mer (a) um
Ufank an am Wuert, (b) um Enn vum Wuert.
(a) Verschloss- a Reiflauter um Ufank an am Wuert
Geschwat ewéi op däitsch — geschriwwe wéi op däitsch.
Ofgesi vun der Aussprooch gët nëmme beim g = [g, j, γ, Ӡ].
Den ch bedeit « ech-Laut »[ç] an « och-Laut »[x] ewéi am Däitschen.
Matbäigeholl gi jh(«franséische j ») fir [Ӡ] an a frieme Wierder c fir [k] an [s], ch fir [k] an [ʃ], ph fir [f], qu fir [k] a v fir [v].
Langues
[g/γ] = g
Den héidäitsche g[g] *) (Verschlosslaut) schwätze mer nëmmen um Ufank vun der Haaptsilb an an der Virsilb ge-; jhust an
Nimm an a geléinte Wierder gët et en och am Wuert
Bagger, Bugrang, Buggi, Neger, Waggong — Beggen, Diggel.
Franséisch Wierder hu g als [g] nëmme virun a, o, u, an l, r, soss muss gu fir [g] stoën
Garage, Glace, Godet, Gourmet, Gros, dégustéieren awer: Gueulard, Guichet, Guide.
De plattdäitsche g[γ] (Reiflaut) gët et nëmmen tëscht Vokaler; d’Ëmgankssprooch kennt e jhust nom kuurzen [ᴜ], oons a
frieme Wierder, wou se n en och no [o:] an [a:] seet. En héiert sech un ewéi e schwaachen [ᴚ], ’t as en «och-Laut» mat Stëmm, ma
mer schreiwen en ëmmer g
Dugend, Kugel, Vugel, ondugen; bedrugen, erzugen, geflugen.
Grad esou schwätze mir de g dacks a geléinte Wierder
Groussherzogin, Jugend, Lager, Tagung.
Fir déi puer Wierder brauche mer keen extrat Zeechen, och nët fir de [j] op Plazen, wou en dem [γ] säi Guet as an och g geschriwwe
gët (vgl. [j] = j/g; Vokaler lb)
Kugel — Kigelchen, Vugel — Vigelchen, verlugen — Ligener.
[k] = k/q/c/ch/qu
De [k]**) steet ewéi am Héidäitschen ëmmer als k (verduebelt: ck); wou tëscht k a Vokal en halwen u geschwat gët, ëmmer als
q. De q gët et nëmmen um Ufank vun enger Silb, néierens um Enn.
Mir schreiwen: Akaul, baken, Bäcker, Deckel, Kabes, kal, Kaz, mackeg, Réck, Sak;
awer: Gequellter, verquëssen, quëtschen, Quetsch, Quisel, quokeleg, Quonk, quot.
A frieme Wierder gi mer de k ganz dacks mat c erëm odder mat qu (op franséisch c virun a, ai, o, u, l, r — qu virun a, ai, é, e, è, ê,
i/d.h. virun a, ai = c od. qu)
Calque, Caisse, Clairon, Contraire, Crayon, Cuvette — Quai, Quartier, Quête, Quiche.
Friem Wierder verdroën och kk an cc: Akkont, Akkuerd, Mokka — Accroc, d’accord.
Mam ch si mer spuersem: Charakter, Christin, chronesch, awer: Kouer, Krëschtdag, Krëschtnech.
[f] = f/v/ph
Den [f] steet als f/v nom Héidäitschen nëmmen um Ufank vun der Haaptsilb a vun de Virsilbe vir- a ver-; soss am Wuert
gemengerhand als f.
Fiischt(First) — viischt(vorderst); féier(führe/fahre!) — véier(vier);
Féi(Feh, Iltis) — Véi(Vieh); fir(für) — vir(vor/vorne); Funn(Fahne) — vun(von).
Wa v am Wuert virkënnt, dann nëmmen do, wou eng Silb ugeet
averstan, Gevuedesch, onverhuckels, onverschimt, Onverstand, Polver.
Jhust a geléinte Wierder, besonnesch wou d’Lëtzebuergescht eng Silb ofgeschlaff huet do steet en och um Enn
aktiv, brav, Nerv, Oktav, Offensiv, Spektiv, Uedem an Éiv;
soubal eng Endong drukënnt, liese mer w[v]: e brave Kärel, Nerven.
A frieme Wierder gët och ph geschriwwen: Geographie, Philharmonie, Katastroph.
[v] = w/v
Den däitsche w (= franséische v) schreiwe mer a Lëtzebuerger Wierder jhust mat w.
Bawel, bleiwen, glewen, Huwwel, kniwwelen, Niwwel, Sewel, Wal, Wee, Wo, Wuurm.
A geléinte Wierder aus dem Franséischen odder dem Laténgeschen, wou d’Héidäitscht gär de v stoë léisst, do hale mir e meeschtens
och: Avis, Enveloppe, Nouvelle, Revue, Vakanz, Vanill, Vas, Verb, vis-à-vis, Visitekaart, Vitamin, Voiture, Volant, Vote, Vue.
Dat heescht awer nët, de w wir hei verbueden; wou d’Wuert duurch d’Aussprooch odder d’Endong méi e Lëtzebuerger Aschlag kritt,
setzt den Dixionär en dacks
Wallissen, Wëlospompel, Wermischel, Wollowang(Vol-au-vent), och: Diwwi, Ziwwi.
[z] = s/z; [s] = s/ss/c/ç/t
Um Ufank vum Wuert huet eis Sprooch nët bal schaarfen [s]; nëmmen a geléinte Wierder, wann een nët léiwer z[ts] an d’Plaz
schwätzt.
Wou [s] geschwat gët, geet um Ufank een s- derfir duer, wann d’friemt Wuert nët c- huet (virun i, é, è, e): Salon, Centre, Cinema,
System — och: Zalong, Zênter, Zinëma, Zistem. A geléinte Wierder kann z- um Ufank awer hei ands do mëllen [z] bedeiten: Zéro, zut !
*) Genee geholl mécht de Phonem g zwou positionell Varianten, déi eist Ouer knaps auserneenhält: [ɟ] virun i, é (= « viischte g »), [g] virun ä, a, o, u (= « mëttelste bis
hënneschte g »). Mir zeechnen déi zwéin hei och phonetesch nëmme mat [g], well néierens eppes ze verwiesslen as. Vgl. **).
**) Grad ewéi de [g] mécht de [k] zwou positionell Varianten: [c] virun i, é (= « viischte k »), [k] virun ä, a, o, u (= « mëttelste bis hënneschte k »). Béides schreiwe mir k,
och phonetesch [k]. An Éislécker Sproochen, wou virun -d-/-t dacks «gutturaliséiert » gët (> -gd-/-kt = epenthetesche -g-/-k virum Dental), léissen sech fir g, k no donkle
Vokaler [ɔ, ᴜ] esouguer [G, q] asetzen (= uvulare g od. k, beim Zäppche mat der hënneschter Zong artikuléiert); ma mir huelen och hei [g] a [k]. Vgl. Sonner Sproochen.
Langues
Am Wuert kënnt mëllen [z] a schaarfen [s] vir
Mir schreiwen am Wuert de mëllen s nëmmen eemol an de schaarfen s nëmmen duebel, de Vokal virdru sief laang odder
kuurz (vgl. Vokaler lc). Den däitschen ß ersetze mer wéinst eise Schreifmaschinnen duurch ss.
mëllen s: broselen, Dosen, Dusel, haseleg, Iesel, Riselen, rosen ;
schaarfen ss: baussen, e bëssen, Deessem, iessen, Stéisser, Täissel.
A frieme Wierder léisst sech awer och z fir [z] an c, t fir [s] schreiwen (ç virun a, o, u)
mëllen s: Gaze, Gazette, Gazon; ganz rar steet och x: Sixième.
schaarfen ss: Demokratie, Explikatioun, Face, Farce, Garçon, Konversatioun, Reçu, Soupçon.
[Ӡ]=jh/g/j
De « franséische j » (mëllen sch) schreiwe mer meeschtens jh
Jhang, Jharr, jhauwen, Jhämp, Jhick, jhummen, jhurren ; grujheleg, knujhelen, Pujhel.
Jhust Wierder, déi hir franséisch Fassong behalen, déi stin deemno virun e mat g/j, virun a, o mat ge/j, virun i, y mat g a virun ou, u
mat j
gentil, Jeton; changeant, Georges, Jaquette, Jolibois; Gilbert, Gymnase; Journal, Jupe, Jus.
[ʃ] = sch(-l,-m,-n,-w)/s(-p,-t)/ch
Wéi am Héidäitsche schreiwe mer um Ufank vun der Silb sch viru p an t nët aus: sp, st; och spl, spr, str. Dat geet ganz gutt,
well mir op där Plaz keemol s-p, s-t schwätzen. Och zesummegesate Wierder kënne mer duerfir mat sp, st schreiwen, soulaang déi zwéin
an eng Silb falen
Spaass, Spill, Spläiter, Spléck, sprock, sprangen — Heesprénger, Holzspläiter, Mondspill.
Stack, stäif, Stréckel, Strumm — Huerstack, Schongstréckel.
Wou mer awer am Wuert sch-p, sch-t op zwou Silbe leën, do muss et ausgeschriwwe gin
baschten, Buschtaf, Eschtrech, Inschpekter, Moschtert, Paschtouer, rëschten, Sieschter; soss liest een s-p, s-t: Aster, Éisträich,
Kasperlek, Lastik, Mastik, pësperen, Vesper.
Besonnesch an Nimm vun Uertschaften heescht et uecht gin
Eeschpelt(Tarchamps),
Ischpelt(Urspelt),
Krëschtnech(Christnach),
Méischtrëf(Mœstroff);
esou
ënnerscheed
ee
gutt
Keespelt(Keispelt), Nouspelt(Nospelt), Uespelt(Aspelt).
Um Enn vum Wuert muss een sch-t ëmmer ausschreiwen, well den s-t gët et och do
Aascht, Frascht, Këscht, Loscht, Rescht — Fest, Poopst, Post, Test.
A franséischen a geléinte Wierder däerf ch fir [ʃ] stoën: Archiven, Châmber, Chauffeur, Chirurg, Couche, Recherche, Tranche.
[j] = j/g
Den «däitsche j » (no beim halwen i) steet um Ufank vum Wuert als j, ma am Wuert (no i, e, éi, l, n, r, t, och virum l) als g
deeglech, digelech, Ierger, Kigelchen, Ligen, méiglech, Segen, Uergel, Vigel (vgl. Vok. lb); och an e sëllechen Uertsnimm
Déilgen(Dillingen), Diengen(Dœnningen), Lëntgen(Lintgen).
Nëmmen a Wierder wéi Andiljen, Familjen, Pompjen, Schantjen, Trueljen, wou d’Franséischt -ier, -ille huet, gët e grad geschriwwen,
wéi e geschwat gët. Dat gëlt och fir Veijoul, vajouleg, wou de j aus dem i kënnt. Dacks schreift sech béides: Billet(Biljee), Oeillet(Oijee).
Och amplaz -ng (-éng, -ong) ka j stoën: Ännerjen, Mengjen, Stelljen (= -ong); no engem i setze mer do awer besser -g-: Ännerigen,
an um Enn -ch, -cht: Andillech, Mengecht asw.
Uertsnimm op -éngen (-éng, -ang) stin dacks mat -gen: Géidgen (Gœdingen), Rullgen (Rullingen), ma ’t wir och kee Feler, se mat
-j- ze schreiwen: Ouljen (Olingen), Rëmëljen (Rümlingen) asw.
Vereenzelt steet a geléinte Wierder och um Ufank g- fir [j]: Generatioun, Generol, Geographie (=hd.[g]/frz.[Ӡ]/lëtzb.[j]!).
[ç/x] = ch
Wéi am Héidäitsche steet ch fir « ech-Laut » [ç] an « och-Laut » [x]. Allebéid komme se nët um Ufank vum Wuert vir.
En « ech-Laut » schwätzt d’Ëmgankssprooch no helle Vokaler (i, e, ä; och ö, ü) an no Konsonanten. En « och-Laut » schwätzt
se no donkle Vokaler (u, o, a).
D’DuebelvokaIer ie an ue gi virum ch (« ech-Laut »!) ié an ué geschwat (ma ouni Stréch um e geschriwwen). ’T muss een ewell
gutt lauschteren, fir deen Ënnerscheed matzekréien.
«éch-Laut»
dichteg, Eechel, Frächen, héichen, Späicher, stiechen, uechter;Ellchen, Meedchen, Spënnchen, Tiitchen.
«och-Laut»
fluchen, broochen, gaachelen; Houchzäit, stauchen.
D’Aussprooch vum « éch-Laut » an der Endong -chen/cher (Diminutiven) wiesselt vun [ç] iwwer [j] bis zum [ɪ]. (Vgl. Hallefkonso
nanten).
(b) Verschloss- a Reiflauter um Enn vum Wuert
Geschwat ewéi op däitsch — geschriwwe wéi op däitsch,
anescht geschwat ewéi op däitsch — geschriwwe wéi geschwat.
Langues
Souwäit d’Lëtzebuergescht an d’Héidäitscht matenee Verschloss- odder Reiflauter hun, souwäit gin s’op déi däitsch Manéier
geschriwwen, mëll odder schaarf — och wa mer wëssen, datt mer déi Lauter um Enn ni mat Stëmm schwätzen: Da’s d’Gesetz
vum haarden Auslaut.
Am Lëtzebuergesche verléiert (grad ewéi am Hd.) um Enn vum Wuert all mëlle Konsonant séng Stëmm (oons l, m, n, ng an r), d.h.
b, d, g, w, s, jh, j gi schaarf geschwat ewéi p, t, k, f, ss, sch, ch. (Virun engem Ufanksvokal am Saz spillt eng aner Regel; vgl. D’Wierder
am Saz, 2.)
Mir soën: Kueben — Kuep, Broden — Brot, Figen — Fi(c)k, Drauwen — Drauf, Nuesen — Nuess, Piijhen — Piisch, Dejen(Tagen)
— Deech(Tage), Laγen(Lagen) — Laach(Lage).
Mir schreiwen: Kueb(plattdt. Kobbe), Fig(Feige/figue), Nues(Nase), Deg(Tage), Lag(Lage).
Nom däitschen (odder franséische) Bild fuere mer an dëse 7 Fäll
lëtzeb. [-p] schreift sech -b/-p: Ribb (Rübe)
— Rëpp (Rippe)
lëtzeb. [-t]
-d/-t: Weid (Weide)
— weit (weit)
lëtzeb. [-k]
-g/-k: Drog (Droge)
— Hok (Haken)
lëtzeb. [-f]
schreift sech -w/-f: Léiw (Löwe)
— Bréif (Brief)
lëtzeb. [-s]
-s/-ss: Dous (Dose)
— grouss (groß)
lëtzeb. [-ç] («ech-Laut») -g/-ch: Deeg (Teig)
— Deech (Dächer)
lëtzeb. [-x] («och-Laut») -g/-ch: Dag (Tag)
— Daach (Dach)
Déi Regel gëlt och, wa méi Konsonanten um Enn beieneestin, z.B.: Stëbs(Staub) — Lëps(Lippe).
Am 8te Fall, dee méiglech as, muss nom franséische Middel de stommen e derbäisin
lëtzeb. [-ʃ] schreift sech -ge/-sch: Loge(loge) — Piisch (pêche/Pfirsisch).
Zum dacksten as awer béides erlaabt: Blamage/Blamaasch, Massage/Massaasch, Tapage/ Tapaasch. (De g liest sech am Wuert wuel
[Ӡ], ma um Enn schwéierlech [ʃ] ouni e hannendrun).
Wann awer e lëtzebuergesche Reiflaut an d’Plaz vun engem däitsche Verschlosslaut kënnt an ëmgekéiert, da schreiwe mer,
wéi mer schwätzen: ëmmer dee schaarfe Laut.
Mir begéinen zesoën nëmmen dës 4 Fäll
lëtzeb. [-f]
amplaz hd.
-b [-b-/-p]
Bouf (Bube) — of (ab)
lëtzeb. [-p]
-f/-pf
op (auf)
— Tromp (Trumpf)
lëtzeb. [-t]
-s/-tzt [-tst]: dat (das)
— gesat (gesetzt)
lëtzeb. [-s]
-chs [-ks]
Fuuss (Fuchs) — Uess (Achse, Ochse)
Déi Ënnerscheder ergin sech aus eiser Sproochgeschicht
D’héidäitsch Lautverschiwwong man eis schaarf Lauter hallef, eis mëll nët mat.
Germ. p, t, k > hd. pf/f, z/s, ch: Pfad, auf; Zaum, was; auch;
> lëtzeb.
Pad, op; Zam, wat; och.
Germ. d, w/f, γ/j > hd. t, b, g
Tür; leben, Leib; Vogel, Vögel;
= lëtzeb.
Dir; liewen, Läif; Vuγel, Vijel ([γ/j] = g geschriwwen).
E puer sënnerlech Fäll bleiwen z’ernimmen
[t] = -d/t
Wou an däitschen Haaptwierder -dt fir -t steet, behale mir -d;
an Zäitwierder bleift -t wéinst der Endong
-d: Stad, Stied, stieds — Uertsnimm wéi Rued(Roodt), Réid(Rœdt), Bëschrued;
-t: hie bënt, hie fënt, dir bant, dir fant (= bind[e]t, find[e]t);
awer: hie spënnt, hie wënnt nom héidäitsche Middel.
A geléinte Wierder däerf -dt stoën: Gesandten, Verwandtschaft.
Wou eist Wuert eenzock mam Däitsche ka verglach gin, schreiwe mer -d odder -t, wéi d’Däitscht et huet (Regel 2b), -dd odder
-tt no eisem kuurze Vokal (Regel 1); wou een d’aalt Wuert nët méi erëmkennt, setze mer -t, wéi mer soën
-d: Bad, Bond, Gedold, Géigend, Heed (Heide), Häerd, Juegd, Leed, Mod, Owend, Soud, Wëld;
-dd: Fridd, Glidd, Judd, Lidd, midd, Ridd, Schmadd, Schmëdd; nom Frans. och: Gidd (guide).
-t: Buet, Brot, Efalt, Fuesent, Heet (Haupt), Nout, Rot, Sot, Spuet, Welt, Wot, Zelt;
-tt: Blutt, Fritt (pomme frite), Gutt, Mitt (Met), Mutt, Nitt, Patt, Rutt, Schnatt, Watt, Wett.
Wou d’aalt Wuert nët méi gewosst as, ëmmer -t: Fuesent, Léngent, Zant (ahd. zand).
Bei Virnimm hale mer -d, sou laang et geet: Bärend, Gierend (Bernard, Gérard).
Am Lëtzebuergesche bleift d’germ. Ofledongssuffix -i ϸô/-iϑô (engl. -th = Adjektivabstraktum) lieweg; mir schreiwen et -t: Déckt,
Déift, Färent, Gréisst, Hëtzt, Héicht, Kränkt, Längt, Léift, Nätzt, Stäärkt, jhust nët, wann op däitsch e Wuert mat -de erhalen as: Freed,
Friemd (obschons bei äis nët < -md + -e!).
Eis Uertsnimm op -feld (-[ƒ]elt), -scheid (-schent), -schleiden (-schelt), kréien -t
Bënzelt(Binsfeld), Heischent(Heiderscheid), Randschelt(Rindschleiden).
Langues
[s] = -s/ss
Um Enn vum Wuert gët no eiser Regel (2b) nëmme schaarf ausgeschwat: -s an -ss bedeiten duerfir hei eent an d’nämmlecht
= schaarfen [s].
Si gi gesat wéi am héidäitsche Wuert: -s fir -s, -ss fir -ss an -ß
Äis, Dous, Gas, Glas, Haus, Rous, weis — Faass, Fouss, grouss, Mooss, séiss, wäiss. Wou d’Lëtzebuergescht [-s] huet amplaz
däitsch -chs[ks] an -z[ts], steet ëmmer -ss: Wuess(Wachs) — Wues(Wasen); e Stéck Weess(Weizen) — e Stéck Wees(Weges).
Elei muss all Kéier verglach gin: Biiss(Büchse), Duess(Dachs), Fluess(Flachs), Fuuss(Fuchs), Héiss(Hachse), Luuss(Luchs),
Uess(Achse/Ochse).
E sonneren s (= Endongs-s/2. Pers. Eenzuel vum Verb, vgl. Konsonanten 1) as ëmmer schaarf [s]: wuer s de gees, ier s de kënns. Ma
en s’ (= si, se vrum Vokal) as am Fong en Ufanks-s: En as mëll [z] odder schaarf [ ̥z = s], deemno wat fir Konsonante virdru kommen, d.h.
mëll nëmmen no l, m, n, ng, r a Vokaler (vgl. D’Wierder am Saz, 2e).
(l, n) + [ts] = -s/ds/ts/z
No l an n schwätze mer den s mat schwaachem t- virdrun *), ma geschriwwe gët nom Däitschen; jhust -tz no l-, n- gët et nët.
-s: als, Bols, eens, Fiels, Gäns, Hals, Hans, maans, oons, wéinstens, zemools;
-ds (d + s-Flexioun): hannerwands, Kandskanner, Opstands, owends;
-ts (t + s-Endong): därbants (binnent/s), nuets, riets; ma uechtgin: hei ands do (und/s!);
-z: Danz, ganz, Kranz, Malz, Mëlz, Mënz, Onz, Pelz, Salz; och: Holz (Holtz!), Wolz (Wiltz!).
Bei Zäitwieder gi mer och uecht op d’Däitscht: du spënns, du wënns; awer: du bënds, du fënds (= bind[e]st, find[e]st), och: du hälts
(= hältst), obschons mir halen (≠ halten) soën.
[ç/x] = -g/ch
Wou mir amplaz héidäitsche -g e Reiflaut schwätzen, « ech-Laut » odder « och-Laut », schreiwe mer a betounten Ennsilben
nom kuurze Vokal nëmmen -ch
Bräch, ewech, Stréch, Zich — Brach, Broch, Zuch.
Nom laange betounte Vokal schwätze mir zesoën nëmmen «ch» [ç/x], ma mir schreiwe -g odder -ch nom Däitschen, och virun
-d/t
Dag(Tag), Deeg(Teig), Éigt(Egge), Juegd(Jagd), Lag(Lage), geluegt(gelegt);
aacht(acht), Daach(Dach), Hiecht(Hecht), Nuecht(Nacht), uecht(acht), geduecht(gedacht).
Wou awer -l- odder -r- tëscht de Vokal an de Reiflaut kënnt, do gëlt den däitsche -g odder -ch; de Vokal sief kuurz odder laang
Bierg(Berg), Biirg(Bürge), Buerg(Borg), Buurg(Burg), Felg(Felge), Suerg(Sorge), uerg(arg).
Däitsch -ch bleift och sin no kuurz a laang: Buerch(Barch), duurch(durch), Perch(Pferch).
Amplaz däitsche -k schreiwe mir -g, wa mer [ç] derfir schwätzen: Muerg(Mark).
An dene puer Wierder, wou mir en héidäitsche -g [k] soën, schreiwe mer -ck, wa mer de Vokal virdru kuurz hun, ma nom r souwéisou
nëmme -k
Flock(Flug), Zock(Zug) - Wierk(Werg).
Geléint Wierder verdroën ëmmer den eenzelne -g um Enn; verduebelt gët do och nom kuurze Vokal nët, wa [-k] gesot gët; ’t sief dann,
’t friemt Wuert hätt ewell -gg
Drog(Droge), Fig(Feige/figue), Grég(Grégoire), Grog(Grog) — Bulldogg(-dogge).
Nom kuurzen onbetounte Vokal bleift och den däitsche -g, ma mir schwätzen ch[ç]
Balleg(Balg), bëlleg(billig), helleg(heilig), Ueleg(Öl, plattdt. Olig);
awer: geféierlech(gefährlich), Kielech(Kelch), Mëllech(Milch) asw.
Eis Adjektiver stin all nom Héidäitschen, oons bestëmmten Endongen
-zeg mat g: bloëlzeg, brongelzeg (héidäitsch: bläulich, bräunlich),
-echt mat ch: geblummelecht, gesprinselecht (hd.: blumig, sprenkelig), grad ewéi: Bäckecht, Hickecht,
jhust nët, wann et Partizipie sin: gesiedegt, verfollegt, vernoléissegt.
Lautkoppelen.
Och bei Konsonantekoppele kann et mat engem Zeechen duergoën, wann se hefeg sin an een se gläich erëmkennt. Mir halen äis bei
[ks] an [ts] un den däitsche Gebrauch
[ks] = chs/cks/ks/x/xc/cc/ct/kt
D’Lautkoppel [ks] schreiwe mer nom Héidäitschen chs, cks, ks, x; ma chs, cks setze mer nëmmen nom kuurze Vokal, ks kann
no kuurz a laang stoën.
Wou mer keen direkte Verglach fannen, huele mer x; natiirlech nët, wa k an s op zwou Silbe falen. Duebelen x gët et nët; laang
Vokaler virdru stin ëmmer zweemol.
Béchs, Eidechs, Ochs, sechs, Wichs; dacks, Gedecks, quiiksen; Aax, féx, Hex, Jux.
*) l an n artikuléiere sech hannert den Zänn; sou héiert een den Iwwergank zum Reiflaut [s] ewéi e schwaache Verschlosslaut [t].
Langues
Mir setzen och: Box, Dixionär (odder: Diktionnär), Lexioun (odder: Lektioun).
ks schreiwe mer selen: Diks(disque), diksen, Maarksdag(Markus-), gaaksen, gierksen.
Nom kuurze Vokal zeechent ks ëmmer d’Lautkoppel an der Stacksilb (= k virun s nët verduebelt: Diks), cks d’Lautkoppel vu Stacksilb
+ s-Endong (= ck bleift: Ge/deck/s).
A frieme Wierder léisst de ks sech grad esou gutt mat cc, ct, cx wéi mat kt, x erëmgin
Accident, Actioun, Excès, extra, fixéieren, mixen, perfektionnéiert, Succès, Taxi.
[ts] = z/tz/zz/ts/t/c/s
D’Lautkoppel [ts] schreiwe mer nom Héidäitschen um Ufank z, am Wuert an um Enn tz odder z (nom kuurzen odder laange
Vokal).
Jhust wann den s nëmmen eng Endong hannerem t mécht, steet ëmmer ts.
zappen, z’iessen, Zill, Zuch — pëtzen, sëtzen; Plaz, spizeg;
awer: Gelitts (= Geléis, Ligen), Gefreets (= Gefroots, Froën), nuets, riets asw.
Flektéiert Zäitwierder op (t)z-s (= 2. Pers. Eenzuel) gi riichtewech -tz/-z geschriwwen
du bitz, du botz, du nätz, du schnäiz, du sëtz, du spëtz, du späiz, du uz;
vgl. dogéint: du bitts, du flitts, du hitts, du litts, du reits, du schneids, du zitts.
A frieme Wierder kann een awer och -t- schreiwen (= lat./frans. -t- fir [ts] od. [s])
[ts]: Patient, Ratioun, Statioun; [s]: Aktiën, Explikatioun, Friktioun.
Muenchmol geet et besser nom däitsche Bild: Präzisioun, Spezialitéit.
Friem Wierder verdroën och zz: Pizza, Razzia, Terrazzo.
De franséischen c- odder s- loosse mer dacks sin, wa mer och schons [ts-] schwätzen
Centre/Zênter; Cercle/Zerkel; Seringue/Zerénk; Service/Zerwiss.
Hallefkonsonanten.
[ɪ] = j/g/ch/i
De [j] iwwerhaapt schwätzt sech der Géigend no méi i odder méi jh; oons dat wiesselt d’Aussprooch gär vun engem zum aner. Mir
gin hei jhust op d’Ëmgankssprooch uecht
Halwe j (halwen [ɪ]) héiert een amplaz [j] virum Vokal an no l, n, r, ma amplaz [ç] besonnesch nom s mat engem Konsonant
virdrun (-ks-, -ls-, -ts-), nët no p, t, k an f.
No l, n, r deit [ɪ] meeschtens op e Wuert, dat sech nët spléckt, ma [ç] op d’Endong -chen, -cher
[ɪ] (geschr. g/j): Gaaljen, Karunjen, Muergen ≠ [ç] (ch): Millchen, Spënnchen, Tiirchen.
Ma -ljen, -njen, -rjen kann och op -ong, -éngen (Uertsnimm) zréckgoën: Erzieljen (Erzählung), Lellgen (Lellingen).
Bei -sç- as et ënnerschiddlech: bëssɪen/bëssçen, Hiesɪen/Hiesçen (geschr.: bësschen, Hieschen), ma bei -ks/j-, -ls/j-, -ns/j-, -ts/j- (= -/
chen) héiert een zum dacksten [ɪ], grad ewéi een no -ld, -mp, -nd, -rf, -rk, -rt, -scht e kloren -ch (éch-Laut) schwätzt.
[ɪ] (geschr. ch!): Béxchen, Dänzchen, Hëlzchen, Witzchen, och: z’j > [tsɪ]: zejoër > zjor;
[ç] (= ch): Bildchen, Lëmpchen, Kierfchen, Määrkchen, Pëndchen, Täärtchen, Wirschtchen, grad ewéi no p, t, k, f eleng: Däppchen,
Frettchen, Jäckchen, Schäffchen.
An Uertsnimm as de -g- hei och [ç] ze liesen: Rëttgen (Roussy-le-Village), Scheedgen (Scheidgen).
[ʃ] + chen geet engem selen iwwer d’Zong; ’t zéckt een do, well soss [ʃ] an [ç] zevill schliirpsen. Léiwer seet een zwou Verklenge
rongen noëneen (el + chen): Dëschelchen, Karmëschelchen.
An all dene Fäll zielt den halwen i fir e Reiflaut, d.h. e Konsonant; ’t as fir äis do ëmmer e j odder en ch. Mir schreiwen e wuel
och -g-, ma keemol i. Am Suffix -chen/cher zielt e fir en ch.
Wou ëmgekéiert awer (a geléinte Wierder) en i viru soss engem Vokal zum [j] gët, do däerf een den i stoëloossen: Braconnier,
Indianer, Reli(gi)oun.
Eréischt wann d’friemt Wuert ganz schanjhéiert, setze mer j: Pampuljen, Spiirkeljoun.
Eng Parti vun eisen -lj-, -nj- geet op franséisch -(i)lle [λ], -gne[ɲ] (palatal Säiten- an Nueslauter) zréck, déi mir schwéier geschwat
kréien. Mir huelen se duerfir gewëssermoosse vuneneen
Bataaljen(bataille), Trueljen(treillis); Punjar(poignard), Schampanjer(Champagne).
[ᴜ] = w/u/o
Halwe w (halwen [ᴜ]) héiert een amplaz [v] no q [k], sch [ʃ] an z [ts].
De w[v] verléiert no [k], [ʃ] an [ts] séng Reiwong, ma amplaz datt em d’Stëmm ausgeet (wéi dacks dem r), gët en hallef zum Vokal,
deen ee wéinst sénger dréiwer Faarf meeschtens fir en u hält, ma dee genee geholl grad sou dacks keen as.
Deemno wat fir e Vokal nokënnt, léiss sech z.B. fir schw- (dréideg geschwat) och soën
schoammen (schwammen), schëenken (schwenken), schöéier (schwéier), Schüier (Schwier), Schuoër (Schwoër).
No k(=q) an ts(=z) kënnt ee bal d’nämmlecht erlauschteren, ma an der Schrëft stéiert den u nët méi wéi de w. Soulaang den Akzent
um Vokal hannendru läit, versteet een [ᴜ], d.h.
Langues
Fir een an deeselwechte Reiflaut [v] stin eng Rëtsch Tëschelauter virum Haaptvokal: all ziele se fir Konsonanten. ’T as fir äis
ëmmer e w, och wou mer nom Héidäitschen u schreiwen.
Quascht, Quitt, Quonk; Schwamp, Schwitz, Schwonk; Zwank, Zwir, gezwongen.
A franséische Wierder Ioossen déi Tëschelauter [ᴜ, y] sech o an u schreiwen; si behalen do hir vokalesch Zeechen: Besoin,
Pointe; Huissier, Puisett.
Franséisch oi[ᴜα] bleift gemengerhand sin — Coiffeur, Croissant, Droit, Toilette, Toile-cirée — bis op déi Plazen, wou d’Betounong
ëmschléit: Toise, Voile > Tues, Wuel.
Och an eisen Duebelvokaler (ai, äi, éi, ie — au, äu, ëu, ue) fanne mer halwen [ɪ], [e] an [ᴜ], [o]; ouni Iwwergank wuesse keng
Vokaler zesummen.
Halleflaang wir ze setzen: aj[αe]; éj[eɪ]; jë[ɪᵊ] — aw[αo]; ëw[Ɵᴜ]; wë[ᴜᵊ];
iwwerlaang wir et
ääj/äji[`æ:j/`εjɪ]; ijë[ìjə]
— ääw/äwu[`æ:ω/`εωᴜ]; uwë[`ᴜωə].
Ma hei zielen s’alleguer als Vokaler; duerfir si se fir äis i an u.
Halleflaang schreiwe mer: ai/ei; éi; ie
au; ou; ue;
iwwerlaang as et
äi;
ie
au;
ue.
D’WIERDER AM SAZ.
DRÄI SPROOCHGEWUNNECHTEN AN DER SCHRËFT.
1. Nët geschwat an nët geschriwwen: Keen -n no der « Äifeler Regel ».
Um Enn vum Wuert fällt am Saz all -n ewech, wann dat Wuert drop mat engem Konsonant ufänkt, oons virun h-, d-, t-, z[ts]-
an n-. Viru Vokaler bleift den -n sin.
Dat bescht Beispill gët de bestëmmte männlechen Artikel
Den Hond, den Dapp, den Tur, den Zuch, den Nol an och: den Aarm, den Äss, den Eck, den Éil, den I, den Ochs, den Uert, den Uz.
Awer: De Ball, de Pëtz, de Gaart, de Kueb, de Vull, de Wee, de Su, de Schong, de Jhick, de Jong, de Läpp, de Mann, de Reen.
Virum s- kann den -n jhust bei si, se, säin, sech, séng, sou a beim sonneren s virun du, de stoëbleiwen: Wann si kommen od. wa si
kommen; wann s de kënns od. wa s de kënns. Bei -n/n- as et dacks schwéier, eng Mol fannen, z.B. en Nascht odder en Ascht ? Wien a
sénger Sprooch dat Ascht seet, kann och en Ascht schreiwen; nët gutt wir e Nascht, well en e virum n léisst sech nët ofsënneren.
Fir Wierder mat méi Silbe gëlt d’Äifeler Regel ëmmer; fir eenzel Silben hält se do stall, wou d’Wuert ouni -n onkloër gët.
Ma och an enger Abberzuel kuurze Wierder si mer un den Ausfall gewinnt
Bei an, dann, däin, de(e)n, din (don, dun), dran, drun, een, gin, hien(en), hin, hun, kann, keen, mäin, nun, säin, schéin, schon, sin, un,
vun, wann, wien, zwéin fällt den -n ewech an all dene Fäll, z.B. haut a mar awer: du an ech.
Och bei de Virsilben an- an un- geet den -n verluer; jhust ni bei on-.
Esou schwätze mer och eis zesummegesate Wierder; an der Fou bleift ëmmer den -n ewech, nëmmen nët virun h-, d-, t-, z- an
n- odder engem Vokal
Birebam, Uewepäif, Drëppeglas, Bounekraitchen, Panewippchen, Quetscheflued, Vullesom, Kaartespill, Schëppestill, Zoppeläffel,
Bokemaul, Millerad.
Awer: Kouertenholz, Leëndecker, Zoppenteller, Kiischtenzäit, Afennoss
an och: Kréiena, Heckenéil, Kolonnenuewen asw.
Mir schreiwen hei ëmmer, wéi mer schwätzen, ausbehale virun engem Komma, engem Ponkt odder soss viru Sazzeechen, wou
een unhëlt, datt d’Ried eng Grëtz stallhält.
Dat Gesetz nennt sech d’Äifeler Regel, well et doiwwer och gëlt. ’T gët laanscht d’däitsch Grenz awer all Kéier duurchbrach, wann e
Wuert mat -n ophält amplaz mat -ng wéi soss am Land, z.B.: en Fra fir eng Fra, keen gout fir keng gutt, gréin Faarf fir gréng Faarf asw.
2. Geschwat, ma nët geschriwwen: Mëll Konsonanten amplaz schaarfer um Enn.
Um Enn vum Wuert gët am Saz all schaarfe Konsonant mëll ausgeschwat, wann dat nächst Wuert mat engem Vokal ugeet.
’T kënne grad esougutt zwéin, dräi Konsonante matenee Stëmm kréien.
Am Däitsche setzt ee virun all Ufanksvokal den Otem frësch un (Knacklaut), ma mir bannen eis Wierder. Guttdäitsch as et: ̕um’elf ̕
Uhr, ma lëtzebuergesch: « ëmelëwauer ».
Ma wa mer eng Schreifweis wëllen hun, déi ze liesen as, dann heescht et, all Wuert schreiwen, wéi wann et fir sech sting. Duer
fir muss hei stoën: Ëm elef Auer. Mir soë wuel: et hierschtzt, an: hierjhdsdet? Ma mir schreiwen: Hierschtzt et? (Herbstet es?)
Op déi nämmlecht Aart a Weis sin eis zesummegesate Wierder ze liesen, wann dee viischten Deel mat engem schaarfe
Konsonant ophält an deen hënneschte mat engem Vokal ugeet.
Mir schwätzen: maddeneen, obbeneen, duurjerneen;
mir schreiwen: mateneen, openeen, duurcherneen.
Mir schwätzen: Knubbauto, Rouda, Viidsapel, Baguewen, Houweisen, grousaarteg, Fëjhaangel, Seejomes;
mir schreiwen: Knuppauto, Routa, Vizapel, Bakuewen, Houfeisen, groussaarteg, Fëschaangel, Seechomes.
Déi Regel gët jhust op e puer Plazen duurchbrach
Langues
(a) Virun dir, der (ihr) gin och d’schaarf Konsonante mëll geschwat.
Geschwat gët: gidder, hudder, dadder, wadder, woumadder;
geschriwwe gët: git der, hut der, datt der, wat der, woumat der.
Den d- un dir war soss d’Endong vum Verb (2. Persoun Plur. = german. -ϑ); méi spéit as se mam ir (ihr) verwuess. Fir richteg géif
d’Firwuert mam i- ufänken; esou gët och nach geschwat (-d/ir). Duerfir gëlt dët nët virun dir, der(dir), dër(deren) an de(du): do bleift de
Konsonant schaarf.
Bei mir, mer (wir) hu mer bal d’selwecht fäärdegbruecht: Aus gin-wer, hun-wer, sin-wer > gi mer, hu mer, si mer. Aus wir, wer gouf
mir, mer.
(b) Virun en(hien), en(hinen), em(him), er(hir) bleift all schaarfe Konsonant sin, ewéi wann den h- nach virum e- sting an
d’Wuert wir betount.
Geschwat gët: Gëf em ës ! (nët: Gëwem ës !) — Ruff en eran ! (nët: Ruwwen eran !) Virun et(hatt) gëlt awer d’Haaptregel wéi iwwe
rall, obschons mer äis och hei den h- virdru mussen denken
Geschwat gët: Geedet mat ? Wëlldet nët ? Geschriwwen: Geet et mat ? Wëllt et nët ?
Den -d gët esouguer da geschwat, wann d’Firwuert zweemol noeneesteet
Geschwat: Fëndededalt ? Geschriwwen: Fënt et et alt? (Fënt hatt dat alt?).
Soubal awer d’Firwuert bis zum ’t zesummeschrompt, wéi meeschtens virum Verb, da gëlt d’Regel nët méi; do héiere mer e schwaa
chen [t]
Mir schwätzen: Haddësst gutt, awer: ’t ësst gutt; (nët: ’dësst gutt, dat géif « dëst Gutt » verstan.)
Mir schreiwen ëmmer t. — Vgl. och (d).
(c) Wou soss um Ufank vum Wuert en [ə-] ausfällt (odder en [-ə] kënnt stoën), do schwätzt een dee schaarfe Konsonant
virdrun awer mëll.
A Fro kommen déi Wierder hei: (e)lauter, (e)lei, (e)leng, (e)lier, (e)lo, (e)luer, (e)niichter, (e)ran, (e)raus, (e)rëm, (e)reem, (e)riwwer,
(e)rop, (e)rof, (e)sou, (e)wech, (e)wéi, (e)well. Dene Wierder hir Geschicht as wuel verschidden (z.B. eran, eraus < her-, elei, elo < alhîe,
aldâ), ma d’Regel as fir s’all d’selwecht. Mir soën: biz(e)ran, gud(e)raus, nëd(e)lei, ma mir schreiwen: bis eran — bis ran, gutt eraus
— gutt raus, nët elei — nët lei.
Jhust no eise schwaachen Eesilber op -e (de = du, se = si) gëlt dat nët ganz, well do fällt jo dann zwemol [-ə+ə-] openeen (= Hiat);
d’ an s’ riichten sech hei nom Laut virdrun: As et e schaarfe Konsonant, si se stomm, as et e mëllen odder e Vokal, behalen se d’Stëmm.
d’ (du) as duerfir ëmmer stomm, wëll et steet jhust no -s od. sonnerem s (vgl. Konsonanten 1),
s’ (si) nët ëmmer, ma och no all schaarfe Konsonant. Duerfir
Ëmmer [ ̥d]: bleifs d’ewech ! gees d’eran !
Awer [z ≠ ̥z]: dro s’eran ! huel s’erëm ! ≠ dréck s’erof ! maach s’erop ! setz s’ewech !
Ze (zu) kënnt virun där Zort Wierder knaps vir; den z’ bleift ëmmer schaarf. — Vgl. och (e).
(d) De bestëmmten Artikel d’ (= F., N. Sg./M., F., N. Pl.) kritt keemol Stëmm, och nët virum Vokal; sou ka kee mengen, ’t wir
e Stéck vum Haaptwuert.
Geschriwwe gët
d’Eess, d’Enn, d’Är;
geschwat gët
t’Eess, t’Enn, t’Är (= [ ̥d]; nët: dees, Denn, Där !),
grad ewéi
’t as, ’t ësst, ’t eelzt (= perséinl. Firwuert: et).
Ma deen t’/’ t as méi e schwaachen t wéi soss um Ufank vum Wuert
[ ̥d] — d ouni Stëmm = [t] — t ouni Hauch (vgl. Konsonanten, 2).
(e) Opfälleg as och, datt eis dräi schwaach Eesilber op -e = de(du), se(si), ze(zu), déi virum Vokal zu d’, s’, z’ zesummeschrompen,
hir ënnerschiddlech Aussprooch behalen
de (= [ ̥də]), ouni Stëmm, well’t steet am nom -s an nom sonneren s[s], duerfir: s ̥de> s d’ [ ̥d = t];
se (= [ ̥zə/zə], stomm nom schaarfen a mat Stëmm nom mëlle Konsonant: ̥ze/ze > s’ [ ̥z/z];
ze (= [tsə]), kritt keemol Stëmm, ma och keen Hauch (z’iessen[ts] ≠ Ziedel[tsh]): tse > z’ [ts].
Wuerfir [də], [zə] d’Stëmm verléieren odder behalen, ergët sech aus deem, wat nokënnt.
’T fällt vläicht manner op, datt dës Grondregel (2) sech och ëmkéiert
Mir bannen d’Wierder och, wa schaarf a mëll Konsonanten openeestoussen.
Um Ufank vum Wuert gët all mëlle Konsonant hallefschaarf geschwat, wann dat Wuert virdru mat engem schaarfen ophält.
All schaarfe Laut fierft op dee mëllen of, ma op alle Fall muss dee mëlle geschriwwe gin.
Mir schwätzen do déi mëll Konsonante wuel jhust hallefschaarf, ma ’t geet duer, fir ierzeleden an zesummegesate Wierder, zemools
an Uertsnimm mat schwaachen Ennsilben. Apaart bei -s/b- > -sp-, -s/d-> -st-, -sch/d-> -scht- as et schwéier ënnerscheden
Mir schwätzen: Betster[-ts ̥d-],
Eespech[-s ̥b-],
Heeschtrëf [-ʃ ̥d-];
mir schreiwen: Betzder(Betzdorf), Eesbech(Eisenbach), Heeschdrëf (Heisdorf).
Bei den Nimm vun de Wochendeg stellt den Dixionär et fräi, Samschdeg/Samschteg ze schreiwen. (Mir lede vun Dag of, nët vun
« Tag », vgl. Méindeg, Freideg, Sonndeg.)
Langues
Amplaz jitfereen schreiwe mer jiddwereen (= jedweder einer).
A Froësätz däerf een d’ëmgestallten Zäit- a Firwierder nët zesummenzéien
Geschwat gët: geeste ? kënnste ? [-s ̥d-]; geschriwwe gët: gees de ? kënns de ?
3. Geschriwwen ewéi geschwat: Mëll Konsonanten am Wuert, schaarfer um Enn.
Dës drëtt Gewunnecht ergët sech aus dem Konsonantekapitel (2b)
Verschloss- a Reiflauter schwätze mer um Ufank an am Wuert mëll odder schaarf, um Enn nëmme schaarf: Da’s d’Gesetz
vum haarden Auslaut.
All Konsonant verléiert d’Stëmm um Enn vum Wuert bis op l, m, n, ng(η), r
[ ̥b = p, ̥d = t, ˚g = k; ̥v = f, ̥z = s, ˚Ӡ = ʃ, ˚ȷ = ç, ˚γ = x]. Ma oons dat huele mer nach eppes an uecht
Um Enn vum Wuert schwätze mer d’Verschloss- an d’Reiflauter wéi am Däitschen (schaarf), ma am Wuert viru ville Flexiven
anescht (mëll). ’T as séier erausfond, wourun dat hält
Mir gesinn hei of vun der Aussprooch virum Vokal am Wuert duerno. Wa jiddwer Wuert och virum Flexiv mat vokaleschem Asaz
(-en, -er, -es) all schaarf Konsonante mëll géif schwätzen, dann hätte mer nees déi vireg Regel. Ma déi spillt nët hei. Elei dréit et sech
jhust ëm Lauter, déi fréier iwerall (virum Flexiv an um Enn) mëll geschwat goufen (wéi nach am Engleschen)
D’Héidäitscht huet haut wuel déiselwecht Uluecht wéi mir am Auslaut, jhust eis mëll Lauter man anerwäerts d’héidäitsch
Lautverschiwwong nët mat
germ. d, w, j/γ = lëtzeb. Dijel, dreiwen, Duγend;
< hd.
Tiegel, treiben, Tugend.
Sou as d’däitsch Schrëft nët fir all eis Fäll geriicht.
Am Héidäitsche kritt all Stacksilb dee Schlusskonsonant geschriwwen, deen se hätt, wann d’Wuert eng Endong krit. Sou
behält d’Wuert séng Schrëft, ’t sief flektéiert odder nët. Op lëtzebuergesch ging dat och, ma mir kéimen da wäit vum däitsche
Bild ewech, dat mer gewinnt sin.
Sou komme mer nët derlaanscht, fir am Wuert mëll Konsonanten amplaz schaarfer ze setzen, soubal mer se soën; um Enn
fuere mer jo wouméiglech nom Däitschen.
(a) -t/-d-
gutt Leit — bei gudde Leiden; eng rout Rutt — där rouder Rudden (hd. -t/(-t-!).
(b) -f/-w-
déif Grief — en déiwe Gruef gruewen; gedriwwen — kee Gedriff (hd. -b/-b-!).
(c) -ch/-j-
en Dag[x] — dës Deg[ç] — an den éischten Degen[j] (hd. -g/-g- grad ewéi hei).
De g[ç/j] mécht villes liicht, ma nawell muss een hei ands do dem Ouer no schreiwen
héich, awer: héijeg, en héijegen od. en héijechen an: deen héchsten, héchstens (chs = [ks]). Absëns och, wann een am Grondwuert de
mëlle [γ/j] nët méi héiert, ma en an der Ofledong als schaarfen ch od. k erëmfënt
bedréien — Bedruch, fléien — Flock, zéien — Zock, Zuch (hd. g/-g-!).
Bei Verben heescht et op déi dräi FäII apaart uechtgin: all mëlle Konsonant gët schaarf, wann d’Endong ewechflitt a virun
-s, -t.
Mir halen d’däitscht Schrëftbild, soulaang et geet, oons wann zwéi Verschlosslauter (Stack + Endong) openeefalen
(a) -d-/-t
lueden - du lueds, lued ! — (d + t > -t): hie luet, dir luet, luet ! (lad[e]t).
Sou leë mer äis och un, wann -nd- zu -nn- gin as
fannen — du fënds(find[e]s[t]), fond([ge]fund[en]), awer: hie fënt(find[e]t).
(b) -w-/-f
schreiwen — du schreifs, hie schreift, schreif ! — geschriwwen.
(c) -g-, -ch-/-g(=ch): Hei kritt een am Wuert gär zweërlee Aussprooch, ma um Enn nëmmen eng: follegen/follechen[j/ç] — du
follegs, hie follegt = du follechs, hie follecht [ç].
Nët vergiessen, datt wuel am Wuert och do virum eenzelne -g-[j/γ] den i an den u sech kuurz liest, ma nët um
Enn (duerfir do -ch, no laange Vokaler och -g)
léien — gelugen[γ], weien — gewigen[j], och: leën — geluegt[ç];
awer: leien — ech luch[x], ech lich[ç] odder: ech loug[x], ech léig[ç].
Zesummegesat Wierder, déi am éischten Deel d’Stacksilb vun engem Verb anhun, stin nom Däitschen (-d/t fir [-t]; -g/ch fir
[-x/ç]) odder mam schaarfe Laut, wou eis Sprooch dervun ofwäicht (lëtzeb. -f amplaz hd. -b).
(a) -d/t: Bestietnes, Brotdëppen, Fondgrouf, Leetnol, Luedstack, Reitpäerd, Rotschléi;
(b) -g/ch: Bleechschossel, Fegfeier, folleglech, Gehäignes, Laachkrämpchen, Schlagsan;
(c) -f
Begriefnes, Dreifjuegd, Hiefbam, Liefkuch, Proufstéck, Schreifmaschin, Wiefstull.
Langues
SONNER SPROOCHEN
Fir eenzel Mondaarten am Land brauche mer weider Zeechen.
Den Dixionär kann se nët all gin; dat hei si méi Virschléi wéi Virschrëften.
1. Vokaler
Laangvokaler
ä [ε˙/`ε::]
fir e
Bän, Stän (Been, Steen) = Areler Säit-Minett/Sauer-Musel·
à [æ˙/ `æ::]
fir e
hàm, nàn (heem, neen) = Iewescht Musel.
o [o˙/ò::]
fir a
Bom, Lof (Bam, Laf) = Ënnescht Guttland/Iewescht Éislek.
ù [ᴜ˙/ `ᴜ::]
fir a
Bùm, Lùf (Bam, Laf) = Iewescht Éislek.
o [ò::]
fir a
Kop, Looch (Kapp, Lach) zesumme mat
e/ä [è::/`ε::]
fir ä
Speek, Weesch/Späk, Wääsch (Speck, Wäsch) = Ur, Ënnersauer, Musel.
o [ò::]
fir äu
Hos, Mos (Haus, Maus) odder
ö [`ø::]
fir äu
Hös, Mös (Haus, Maus) zesumme mat
e/ä [è::/`ε::]
fir äi
weess, Ween/wääss, Wän (wäiss, Wäin) = Areler Säit.
ö [ø˙/`ø::]
fir ue
hölen, mölen (huelen, muelen) odder
ù [o˙/ò::]
fir ue
hùlen, mùlen (huelen, muelen) mat
e [e˙/è::]
fir ie
Heel, Meel (Hiel, Miel) = Ënnescht Éislek/Iewescht Guttland.
à [`α::]
fir a
Kàànd, Màn (Kand, Mann) mat
ë/e [`Ɵ::/è::]
fir ë
hëënt, Mëënsch/heent, Meensch (hënt, Mënsch),
ä [`ε::]
fir ä
Gräänz, häl (Grenz, hell) an
o [ò::]
fir o
Hoond, Moond (Hond, Mond) = Belsch a loutréngesch Säit.
Duebelvokaler
au [`α:o/`α:ᴜ]
fir a
Kaund, Maun (Kand, Mann) mat
éi [è:ɪ]
fir ë
héint, Méinsch (hënt, Mënsch),
ou [`Ɵ:ᴜ]
fir o
Hound, Mound (Hond, Mond) an
ä/äi [`ε::/`ε:ɪ]
fir ä
Gräänz, hääl/häinken, Käinki (hänken, Känki) = Areler Säit.
éi [è:ɪ]
fir äi
Éis, Péif (Äis, Päif) mat
ou [`Ɵ:ᴜ]
fir äu
ous, Rout (aus, Raut) = Ur, Ënnersauer, Musel.
au [`:ɐ:o/`αᴜ:]
fir äu
Haut, Strauss (Häut, Sträuss schreift sech d’selwecht!) mat
ai [`:ɐ:e/`αɪ:]
fir äi
drai, naischt (dräi, näischt) = Dickerech/d’Stad.
oa [ɔ˙/`ɔ::]
fir ue
Noacht, oacht (Nuecht, uecht) = Éislek (Wolz, Veianen)/Iechternach.
oa [ɔα˙/`ɔ:α]
fir a
Goart, Moart (Gaart, Maart) = Ënnescht Guttland.
oa/öä [ɔʌ˙/œ`ɜ::]
fir a/ue: Goart, Noacht/Göärt, Nöächt = Kiischpelt.
äe [εə/ `æ:ɐ]
fir e
näen, Wäess (neen, Weess) = Areler Säit;
fir ie
äech, äessen (iech, iessen) = Ënnescht Guttland.
oi [ɔʏ]
fir éi
Boier, Koi (Béier, Kéi) = Areler Streech.
uë- [u:ə]
fir oue-
Uër, wuër (Ouer, wouer) mat
ië- [i:ə]
fir éie-
miën, siër (méien, séier)=Éislek (Äifeler Säit, Heed)/Ënnersauer.
ua/uä [ᴜα/ᴜε] fir ue
Kuall, Uawwen/Kuäll, Uäwwen (Kuel, Uewen) mat
uoo/uee [ᴜ`ɔ::/ᴜè::]
Uooss, Wuoort/Ueess, Wueert (Uess, Wuert) an
iä [ɪε]
fir ie
Liäwwen, Wiädder (Liewen, Wieder) mat
iää [ɪ`ε::]
Kniää(ch)t, siäächt (Kniecht, siecht) = Iewescht Éislek.
uaa [ᴜa˙/ɔα˙]
fir u/ue
Huaan, Huaas (Hunn, Hues) mat
iää [ɪæ˙/eɐ˙]
fir ie
Liääwen, Wiääder (Liewen, Wieder) = Veianen.
aï [`α:ɪ] (aï = a + j) fir ue + ch: aït, Naït (uecht, Nuecht) = Iewescht Éislek (Heed).
A muenech Sprooche geet an e puer kuurze Wierder ee Vokal virum Konsonant nët duer, fir e laang ze liesen, z.B. éisléckesch
aan(un), och aan(an) asw. Verduebelt gët elei och, wa mer zesummesetzen: aapacken, draakreien (upaken, drukréien).
Wou tëscht i/u an t en -ch- ausfällt, stinn i/u och vrum t eleng duebel: Fruut, riit (Fruucht, riicht), vgl. 2.
2. Konsonanten
çh [ç]
fir ch [x]
daçh, Woçh, Zuçh (« ech-Laut » och no a, o, u) an
j [j]
fir g [γ]
Lajer, frojen, gezujen ([j] och no a, o, u) = Iewescht Éislek.
sch [ʃ] fir ch [ç]
ësch, fäerdësch ([ç] < [ʃ]) = Ur, Sauer, Minett.
ckt [kt] fir -t
hockt, Leckt; Huckt, Lickt (haut, Leit; Hutt, Lidd) an
gd [gd] fir –d-
logden, wegder; Brugder, figderen (lauden, weider; Brudder, fidderen) = Éislek an Areler Streech.
st [st]
fir –scht(-)
gester, Këst (gëschter, Këscht) = Éislek, Tréiesch Säit.
scht [ʃt] fir –st(-)
Fënschter, Poscht (Fënster, Post) = Ënnescht Guttland.
t [t]
fir –cht(-)
Liit, Uut (Liicht, Uucht / Vokal duebel schreiwen!) = Iewescht Éislek/ Ënnescht Guttland.
d’ [d]
fir [ ̥d]
D’Iewescht Heed schwätzt, grad ewéi d’Äifeler Éislek an d’Neibelscht, den d’ virum Vokal zum
dackste mëll (= [d])
Kuggemolobd’ Auer ! E Konsonant virdru kritt da mat Stëmm. Anerwäerts am Land wir et
Kuggemolop t’Auer!
Ma geschriwwe gët ëmmer jhust d’.
Langues
Règlement grand-ducal du 6 juillet 1994 portant création de certificats et diplômes
attestant la compétence de communication en langue luxembourgeoise. 1
(Mém. A - 68 du 27 juillet 1994, p. 1215)
Il est créé une certification de la compétence de communication en langue luxembourgeoise comportant différents niveaux.
Les certifications instituées par le règlement grand-ducal du 6 juillet 1994 attestent séparément les compétences de communi
cation à l’oral et à l’écrit. Elles certifient les niveaux suivants
1. Lëtzebuergesch als Friemsprooch
1.1. -
Compétences à l’oral
1.1.1.- Compréhension
Niveau de base: Zertifikat, Lëtzebuergesch als Friemsprooch, Héierverständnes
Niveau moyen
Éischten Diplom, Lëtzebuergesch als Friemsprooch, Héierverständnes
Niveau avancé
Zweeten Diplom, Lëtzebuergesch als Friemsprooch, Héierverständnes
1.1.2.- Expression
Niveau de base: Zertifikat, Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
Niveau moyen
Éischten Diplom, Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
Niveau avancé
Zweeten Diplom, Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
1.2. -
Compétences à l’écrit
1.2.1.- Compréhension
Niveau de base: Zertifikat, Lëtzebuergesch als Friemsprooch, Liesverständnes
Niveau moyen
Éischten Diplom, Lëtzebuergesch als Friemsprooch, Liesverständnes
Niveau avancé
Zweeten Diplom, Lëtzebuergesch als Friemsprooch, Liesverständnes
1.2.2.- Expression
Niveau de base: Zertifikat, Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
Niveau moyen
Éischten Diplom, Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
Niveau avancé
Zweeten Diplom, Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
Tout candidat est libre de se présenter aux épreuves pour la certification de l’une de ces compétences seulement. En conséquence,
l’examen est à organiser de façon qu’un candidat puisse se soumettre aux épreuves de compréhension et/ou d’expression à l’oral et
ait une certification de son niveau dans la compréhension et/ou l’expression orales. De même, il pourra se soumettre à des épreuves
de compréhension et/ou d’expression à l’écrit et se faire certifier sa maîtrise de la compréhension et/ou de l’expression écrites.
Lors d’une même session d’examen, une inscription à la même compétence à des niveaux différents n’est pas possible.
2. Ieweschten Diplom Lëtzebuergesch
Niveau: maîtrise de la langue telle qu’on peut l’attendre d’une personne de même niveau de formation qui parle, lit et écrit sa
langue maternelle.
L’examen comporte à la fois des épreuves d’oral et d’écrit, de compréhension et d’expression: Héierverständnes - Mëndlechen
Ausdrock - Liesverständnes - Schrëftlechen Ausdrock. Le «Ieweschten Diplom Lëtzebuergesch» n’est octroyé qu’au candidat ayant
réussi les quatre compétences. Toutefois, un certificat attestant séparément les compétences dans lesquelles le candidat a réussi,
peut être établi sur demande.
Langues
Les certifications portent sur les niveaux de compétence suivants
– «Zertifikat Lëtzebuergesch als Friemsprooch» correspondant au «Level One: Waystage User», défini par le Conseil de l’Eu
rope;
– «Eischten Diplom Lëtzebuergesch als Friemsprooch» correspondant au «Level Two: Threshold User», défini par le Conseil
de l’Europe;
– «Zweten Diplom Lëtzebuergesch als Friemsprooch» correspondant au «Level Three: Independent User», défini par ALTE
(Association of Language Teachers in Europe);
– «Ieweschten Diplom Lëtzebuergesch» certifiant une maîtrise de la langue semblable à celle d’un autochtone.
Pour chaque niveau, il y a une certification séparée des compétences à l’oral et à l’écrit.
Les certifications «Lëtzebuergesch als Friemsprooch» attestent les compétences suivantes
1. Niveau de base
- Zertifikat, Lëtzebuergesch als Friemsprooch, Héierverständnes
- Zertifikat, Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
- Zertifikat, Lëtzebuergesch als Friemsprooch, Liesverständnes
- Zertifikat, Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
L’examen certifie les compétences fixées par le Conseil de l’Europe pour le niveau A2 du CADRE EUROPÉEN COM
MUN DE RÉFÉRENCE
Le candidat peut comprendre des expressions et un vocabulaire très fréquent relatifs à tout ce qui le concerne de
près. Il peut faire une série de phrases simples pour décrire des personnes, ses conditions de vie et sa situation pro
fessionnelle. Il peut lire et trouver une information particulière dans des textes courts très simples et des documents
courants. Il peut écrire des notes et messages simples relatifs à des besoins immédiats et une lettre personnelle très
simple.
2. Niveau moyen
- Éischten Diplom, Lëtzebuergesch als Friemsprooch, Héierverständnes
- Éischten Diplom, Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
- Éischten Diplom, Lëtzebuergesch als Friemsprooch, Liesverständnes
- Éischten Diplom, Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
L’examen certifie les compétences fixées par le Conseil de l’Europe pour le niveau B1 du CADRE EUROPÉEN COM
MUN DE RÉFÉRENCE
Le candidat peut comprendre l’essentiel d’énoncés clairs et courants sur des sujets familiers. Il peut raconter des
événements ou une histoire, donner des explications et exprimer ses sentiments. Il peut comprendre des textes rela
tifs à la vie quotidienne, la description d’événements et l’expression de sentiments. Il peut écrire un texte simple et
cohérent sur des sujets d’intérêt personnel, décrire des expériences et impressions.
3. Niveau avancé
- Zweeten Diplom, Lëtzebuergesch als Friemsprooch, Héierverständnes
- Zweeten Diplom, Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
- Zweeten Diplom, Lëtzebuergesch als Friemsprooch, Liesverständnes
- Zweeten Diplom, Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
L’examen certifie les compétences fixées par le Conseil de l’Europe pour le niveau B2 du CADRE EUROPÉEN
COMMUN DE RÉFÉRENCE
Le candidat peut comprendre des discours longs, les informations télévisées et des films en langue standard. Il peut
s’exprimer de façon détaillée sur une grande gamme de sujets relatifs à ses centres d’intérêt. Il peut lire des articles
et des comptes rendus sur des questions contemporaines et un texte littéraire en prose. Il peut écrire un rapport,
transmettre des informations et donner des raisons pour ou contre une opinion donnée.
Le Centre de langues Luxembourg est chargé de l’organisation des examens en vue de ces certifications. Les certificat et
diplômes, établis par le Centre de langues Luxembourg, sont contresignés par le ministre de l’Education nationale et enregistrés
au Service de la formation des adultes.
Pour les certifications «Lëtzebuergesch als Friemsprooch», parties «oral» et «écrit», les épreuves sont fixées comme suit
1 -
Compréhension de l’oral
1.1.
Niveau de base
Zertifikat Lëtzebuergesch als Friemsprooch, Héierverständnes
Compréhension globale d’un court dialogue enregistré, d’une durée maximale de 1 minute ainsi qu’une épreuve de dis
crimination phonétique.
1.2.
Niveau moyen
Éischten Diplom Lëtzebuergesch als Friemsprooch, Héierverständnes
Compréhension d’un dialogue ou d’une interview enregistrés, d’une durée maximale de 1,5 minutes ainsi qu’une épreuve
discriminatoire d’intonation.
1.3.
Niveau avancé
Zweeten Diplom Lëtzebuergesch als Friemsprooch, Héierverständnes
Compréhension d’un enregistrement authentique tiré de la vie sociale, professionnelle ou culturelle, d’une durée maxi
male de 2 minutes.
2 -
Expression orale
2.1.
Niveau de base
Zertifikat Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
Présentation de sa personne et de son cadre de vie et description d’un objet, d’une personne, d’un événement.
Langues
2.2.
Niveau moyen
Éischten Diplom Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
Prise de position personnelle sur un sujet d’intérêt général ainsi que description avec commentaire d’une situation ou d’un
événement.
2.3.
Niveau avancé
Zweeten Diplom Lëtzebuergesch als Friemsprooch, mëndlechen Ausdrock
Prise de position détaillée et argumentée sur un sujet d’intérêt général.
3 -
Compréhension de l’écrit
3.1.
Niveau de base
Zertifikat Lëtzebuergesch als Friemsprooch, Liesverständnes
Compréhension globale d’une note, d’une annonce, d’un texte courts et simples.
3.2.
Niveau moyen
Éischten Diplom Lëtzebuergesch als Friemsprooch, Liesverständnes
Compréhension globale et détaillée de communications courtes de la vie publique.
3.3.
Niveau avancé
Zweeten Diplom Lëtzebuergesch als Friemsprooch, Liesverständnes
Compréhension globale et détaillée de textes d’une certaine complexité tirés de la vie sociale ou professionnelle.
4 -
Expression écrite
4.1.
Niveau de base
Zertifikat Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
Rédaction d’une courte note, d’un message personnel à l’aide de phrases simples.
4.2.
Niveau moyen
Éischten Diplom Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
Rédaction de textes simples et cohérents sur des sujets familiers dans une langue simple.
4.3.
Niveau avancé
Zweeten Diplom Lëtzebuergesch als Friemsprooch, schrëftlechen Ausdrock
Rédaction de textes cohérents, personnels ou professionnels, dans une langue adaptée à la situation.
Sont admissibles aux épreuves tous les candidats, résidents ou non, qui en expriment le désir en s’inscrivant avant la date limite.
La certification «Ieweschten Diplom Lëtzebuergesch» atteste une maîtrise de la langue semblable à celle d’un autochtone.
A l’oral, le candidat a approximativement la même aisance dans la compréhension et l’expression que dans sa langue mater
nelle. Il sait communiquer et discuter sans problèmes dans toutes les situations de la vie sociale, professionnelle et culturelle.
A l’écrit, il comprend les textes d’actualité ou littéraires dans le détail. Il s’exprime d’une manière pertinente et fluide, tout en
respectant l’orthographe, sur tous les faits de la vie économique, sociale ou culturelle.
L’inscription aux examens n’est pas soumise au paiement d’une taxe. Toutefois une participation aux frais dont le montant maxi
mum est à fixer par le ministre de l’Education nationale est demandée aux candidats.
Teneur et forme des certificats et diplômes
Les certificats et diplômes mentionnent les nom, prénom, date et lieu de naissance et nationalité du candidat ainsi que le nom
du certificat ou diplôme obtenu, avec spécification des compétences.
Pour chacun des certificats ou diplômes, distinction est faite entre
– Héierverständnes
– mëndlechen Ausdrock
– Liesverständnes
– schrëftlechen Ausdrock
Au verso, chaque certificat et diplôme porte une note explicative en français ou en luxembourgeois concernant les compétences
attestées.
Les certificats et diplômes sont établis par le Centre de Langues Luxembourg et signés par le président et le secrétaire du jury.
Ils sont contresignés par le ministre ayant l’éducation des adultes dans ses attributions, ou par son délégué.
Il y a au moins une session d’examen par an. Les dates et lieux des épreuves ainsi que la date limite des inscriptions sont publiés
par voie de la presse. Des antennes régionales peuvent fonctionner en cas de nécessité.
Modalités d’organisation
Le Centre de Langues Luxembourg est chargé de l’information sur les examens. Au moins un mois avant la date limite des ins
criptions, il publie dans la presse les dates et lieux des épreuves tout en mentionnant la date limite des inscriptions.
Le droit à l’inscription aux examens n’est pas soumis à des conditions particulières, ni de résidence ni de fréquentation d’un
cours.
Le Centre de Langues Luxembourg reçoit les inscriptions écrites sur formulaires mis à la disposition des candidats. Il convoque
les candidats aux épreuves d’après un schéma établi par le jury.
Langues
Chaque candidat participe aux frais d’organisation de l’examen. Il verse à Langues et Culture asbl, chargée de la gestion des
examens étrangers du Centre de Langues Luxembourg, un montant non remboursable, à déterminer par le jury en fonction des
frais réels. Ce montant ne peut dépasser 50 EUR.
Le certificat ou diplôme n’est délivré au candidat qu’après versement de sa participation aux frais d’organisation.
Le ministre de l’Education nationale fixe les contenus des examens et les critères d’évaluation.
Contenu et déroulement des épreuves, évaluation des épreuves
Les épreuves d’expression orale sont passées individuellement devant deux examinateurs. Les examinateurs notent leur appré
ciation immédiatement après le passage du candidat. A cette fin, ils se servent du barème d’appréciation que le jury aura élaboré
ensemble avec les épreuves. La note obtenue par le candidat dans une épreuve est la moyenne des notes données par les deux
examinateurs.
Les épreuves de compréhension de l’oral, de compréhension de l’écrit et d’expression écrite sont des épreuves communes.
Chaque épreuve est corrigée par deux examinateurs. La note obtenue est la moyenne des notes attribuées par chacun des exa
minateurs.
Compte tenu des appréciations, le jury décide de la réussite d’un candidat, séparément pour chaque compétence. Les certifica
tions en luxembourgeois ne prévoient pas de mentions de distinction.
Au cours des épreuves, les instructions des examinateurs sont à observer de façon stricte. Tout non-respect de ces instructions
peut entraîner, le cas échéant, l’exclusion du candidat de la session en cours.
Le Centre de Langues Luxembourg établit les certifications et archive les résultats. Après signature par le jury, celui-ci transmet
les certifications, pour signature, au ministre ayant l’éducation des adultes dans ses attributions. Elles sont enregistrées par le
Service de la formation des adultes.
Le ministre de l’Education nationale établit une liste des enseignants habilités à faire partie du jury d’examen. Cette liste est
remise à jour au moins tous les trois ans.
Le présent règlement ministériel remplace et abroge le règlement ministériel du 28 novembre 1994 portant certification des
compétences de communication en luxembourgeois.
Le ministre de l’Education nationale désigne le jury d’examen pour la durée d’une année civile. Le jury se compose d’au moins
trois membres effectifs et six membres suppléants.
Les membres effectifs et les membres suppléants du jury peuvent être examinateurs aux épreuves orales et aux épreuves
écrites. Chacune des épreuves est évaluée par deux examinateurs.
Le directeur ou le directeur adjoint du Service de la formation des adultes est d’office président du jury. Le jury désigne en son
sein le secrétaire.
Dès la nomination du jury, le président réunit les membres effectifs et les membres suppléants pour organiser les sessions
d’examen de l’année. Le jury désigne l’ordre dans lequel il est fait appel aux suppléants comme examinateurs en cas de nécessité.
Il fixe les procédures d’examination et d’évaluation. Il fait élaborer et choisit les épreuves.
Le jury a l’obligation de garder le secret en ce qui concerne les épreuves et les délibérations.
Le jury prend ses décisions à la majorité simple des voix des membres participant aux délibérations. En cas d’égalité des voix,
celle du président est prépondérante.
1 Bases légales: Loi du 24 février 1984 sur le régime des langues et Loi du 19 juillet 1991 portant création d’un Service de la formation des adultes et donnant
un statut légal au Centre de langues Luxembourg.
Langues
Le ministre de l’Education nationale fixe le modèle des certificats et diplômes.
Les indemnités des membres du jury sont fixées par le Gouvernement en Conseil.
Les résultats des épreuves passées avec succès pendant la session d’examen qui a fonctionné à l’essai en 1994 peuvent être
validés par le ministre de l’Education nationale et permettre l’obtention des certifications prévues dans le présent règlement.
Notre ministre de l’Education nationale est chargé de l’exécution du présent règlement, qui sera publié au Mémorial.
Règlement ministériel du 29 janvier 2001 portant certification des compétences de communication en luxembourgeois.
(Mém. A - 22 du 20 février 2001, p. 738)